@@ -1,15 +1,18 @@
 '''Memory and disk cache for functions'''
 
-__version__ = '0.2'
+__version__ = '0.3'
 
 import functools
 from hashlib import md5
 from pathlib import Path
 import os
+import inspect
 import pickle
 import logging
 import copy
 
+logger = logging.getLogger(__name__)
+
 def memoize(
         cache_dir='tmp',
         memory_cache=True,
@@ -40,11 +43,9 @@ def memoize(
         def wrapper(*args, **kwargs):
             hasher = md5()
 
-            # TODO: make this work
-            # hasher.update(pickle.dumps(func))
-            # inspect.getsource(f).encode("utf-8")
-            [hasher.update(pickle.dumps(a)) for a in args]
-            {hasher.update(pickle.dumps(v)) for k,v in kwargs.items()}
+            hasher.update( inspect.getsource(func).encode() )
+            [hasher.update( pickle.dumps(a) ) for a in args]
+            {hasher.update( pickle.dumps(v) ) for k,v in kwargs.items()}
 
             key = hasher.hexdigest()
 
@@ -55,12 +56,12 @@ def memoize(
             # memory cache
             if not invalidate_cache and key in cache:
                 result = copy.deepcopy(cache[key])
-                logging.info(f'Memory cache hit for {func.__name__} with key {key}.')
+                logger.info(f'Memory cache hit for {func.__name__} with key {key}.')
 
             # disk cache
             elif not invalidate_cache and path.is_file():
                 result = pickle.load( open(path, 'rb') )
-                logging.info(f'Disk cache hit for {func.__name__} with path {path}.')
+                logger.info(f'Disk cache hit for {func.__name__} with path {path}.')
 
                 if memory_cache:
                     cache[key] = copy.deepcopy(result)
@@ -68,7 +69,7 @@ def memoize(
             # evaluate function
             else:
                 result = func(*args, **kwargs)
-                logging.info(f'Cache miss for {func.__name__} with key {key}.')
+                logger.info(f'Cache miss for {func.__name__} with key {key}.')
 
                 if memory_cache:
                     cache[key] = copy.deepcopy(result)
